@@ -3,12 +3,13 @@ from builtins import object
 import json
 import requests
 
+from .constants import K_NOTIF_API_KEY
 from .constants import K_NOTIF_API_URL
 
 
 class NotifApi(object):
 
-    def __init__(self, api_key):
+    def __init__(self, api_key=K_NOTIF_API_KEY):
         self.notif_service_url = K_NOTIF_API_URL
         self.api_key = api_key
 
